@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 10.10's 2.6.35 kernel.
+# This is kernel build script for ubuntu 10.04's 2.6.32 kernel.
 #
 
 update_maintainer () {
@@ -18,8 +18,7 @@ die () {
     exit 1
 }
 
-#VERSION=`uname -r | cut -d - -f 1,2`
-VERSION=`apt-cache search ^linux-image-2.6.35-..- | cut -b 13-21 | awk ' { print $1 }' | sort -r | uniq | head -n 1`
+VERSION=`apt-cache search ^linux-image-2.6.32-..- | cut -b 13-21 | awk ' { print $1 }' | sort -r | uniq | head -n 1`
 export CONCURRENCY_LEVEL=`grep -c '^processor' /proc/cpuinfo` || die "Can't export."
 
 apt-get -y install wget
@@ -31,9 +30,9 @@ done
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.3-20130117.tar.gz ]
+if [ ! -r ccs-patch-1.7.3-20131019.tar.gz ]
 then
-    wget -O ccs-patch-1.7.3-20130117.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20130117.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.7.3-20131019.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20131019.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -44,10 +43,10 @@ apt-get source linux-image-${VERSION}-generic-pae || die "Can't install kernel s
 apt-get install linux-headers-${VERSION} || die "Can't install packages."
 
 # Apply patches and create kernel config.
-cd linux-2.6.35/ || die "Can't chdir to linux-2.6.35/ ."
+cd linux-2.6.32/ || die "Can't chdir to linux-2.6.32/ ."
 update_maintainer
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.7.3-20130117.tar.gz || die "Can't extract patch."
-patch -p1 < patches/ccs-patch-2.6.35-ubuntu-10.10.diff || die "Can't apply patch."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.7.3-20131019.tar.gz || die "Can't extract patch."
+patch -p1 < patches/ccs-patch-2.6.32-ubuntu-10.04.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*generic-pae*'`; do cp -p $i `echo $i | sed -e 's/generic-pae/ccs/g'`; done
 for i in debian.master/config/*/config.common.*; do cat config.ccs >> $i; done
@@ -55,28 +54,26 @@ rm debian.master/control.stub || die "Can't delete control.stub."
 make -f debian/rules debian.master/control.stub || die "Can't update control.stub."
 rm debian/control || die "Can't delete control."
 debian/rules debian/control || die "Can't update control."
-for i in debian.master/abi/2.6.35-*/*/ ; do touch $i/ccs.ignore; done
+for i in debian.master/abi/2.6.32-*/*/ ; do touch $i/ccs.ignore; done
 
 # Make modified header files go into local header package.
 patch -p0 << "EOF" || die "Can't patch link-headers."
 --- debian/scripts/link-headers
 +++ debian/scripts/link-headers
-@@ -39,4 +39,19 @@
+@@ -39,4 +39,17 @@
  done
  )
  
 +if [ $flavour == "ccs" ]
 +then
 +    cd $hdrdir/../../../../$symdir/usr/src/$symdir/include/linux/
-+    for i in sched.h init_task.h security.h ccsecurity.h
++    for i in sched.h init_task.h ccsecurity.h
 +    do
 +	rm -f $hdrdir/include/linux/$i
 +	cp -p $i $hdrdir/include/linux/$i
 +    done
-+    rm -f $hdrdir/include/net $hdrdir/security
-+    cd ../
-+    tar -cf - net | ( cd $hdrdir/include/ ; tar -xf - )
-+    cd ../
++    rm -f $hdrdir/security
++    cd ../../
 +    tar -cf - security | ( cd $hdrdir ; tar -xf - )
 +fi
 +
